search_cd_ng: Search a congressional district using an explicit data bundle

View source: R/ng_functions.R

search_cd_ngR Documentation

Search a congressional district using an explicit data bundle

Description

Search a congressional district using an explicit data bundle

Usage

search_cd_ng(data, state_fips_code, congressional_district)

Arguments

data

A zipcodeR_data_bundle.

state_fips_code

One state FIPS code.

congressional_district

One two-digit district code.

Value

A ZIP-to-district tibble.


zipcodeR documentation built on Sept. 7, 2026, 5:06 p.m.