zip_data_version: Report zipcodeR data-version metadata

View source: R/data_bundle.R

zip_data_versionR Documentation

Report zipcodeR data-version metadata

Description

With no argument, reports the immutable data bundled with the legacy API. Given a downloaded data bundle, reports that bundle's metadata and verified checksum.

Usage

zip_data_version(x = NULL)

Arguments

x

NULL for the legacy bundled data, or a zipcodeR_data_bundle object.

Value

A named metadata list.


zipcodeR documentation built on Sept. 7, 2026, 5:06 p.m.