Learn R Programming

zipcodeR (version 0.4.0)

zip_data_version: Report zipcodeR data-version metadata

Description

With no argument, reports the immutable data bundled with the legacy API. Given a downloaded data bundle, reports that bundle's metadata and verified checksum.

Usage

zip_data_version(x = NULL)

Value

A named metadata list.

Arguments

x

NULL for the legacy bundled data, or a zipcodeR_data_bundle object.